@@ -1,20 +1,21 @@
+# -*- coding: utf-8 -*-
 ##################################################################################
-#    Copyright (c) 2004-2009 Utah State University, All rights reserved. 
+#    Copyright (c) 2004-2009 Utah State University, All rights reserved.
 #    Portions copyright 2009 Massachusetts Institute of Technology, All rights reserved.
-#                                                                                 
-#    This program is free software; you can redistribute it and/or modify         
-#    it under the terms of the GNU General Public License as published by         
-#    the Free Software Foundation, version 2.                                      
-#                                                                                 
-#    This program is distributed in the hope that it will be useful,              
-#    but WITHOUT ANY WARRANTY; without even the implied warranty of               
-#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                
-#    GNU General Public License for more details.                                 
-#                                                                                 
-#    You should have received a copy of the GNU General Public License            
-#    along with this program; if not, write to the Free Software                  
-#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA    
-#                                                                                 
+#
+#    This program is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation, version 2.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
 ##################################################################################
 
 __author__  = '''Brent Lambert, David Ray, Jon Thomas'''
@@ -41,7 +42,7 @@ except ImportError:
     CustomizationPolicy = None
 
 from AccessControl import allow_module
-from Globals import package_home
+from App.Common import package_home
 from Products.Archetypes import listTypes
 from Products.Archetypes.atapi import *
 from Products.Archetypes.utils import capitalize
